/*******************************************************************************
*
*         USING THE EXTERNAL INTERRUPT 0 TO ENTER AN INTERRUPT SUBROUTINE
*         ---------------------------------------------------------------
*
*   Filename:                                    
*   Autor:                  David Kress
*
*   Version:                1.0
*   Date:                   5. August 2013
*   Built with:             ATMEL AVR Studio 4.14 and AVR-GCC; Optimization -01
*
*   Description:            This programm is a simple example how to detect an
*                           external interrupt on INT0 and entering the
*                           interrupt subroutine. The subroutine will toggle 
*                           a digitalport which can be visualized with an led or
*                           or a dc voltmeter. The interrupt is caused by a
*                           faling edge.
*                           Notice, that this program doesn't contains 
*                           switch debouncing. So it could be, that the led goes
*                           off again immediately.
*                           
*   What you can learn:     - Enabel the external interruptsource INT0
*                           - Configurate INT0 for falling edge interrupt
*                           - Write the subroutine for INT0
*
*   Recommended             - High: 0xD9
*   Fuse settings:          - Low:  0xE4
*
*   Schematic:       ___________________
*                   |      ATMEGA8      |
*          Vcc ---->|Vcc                |
*          Vcc ---->|RESET              |
*                   |                   |
*          GND ---->|GND                |
*                   |                   |
*            \      |                   |
*    GND ---  \o--->|PD2 (INT0)      PB0|----> DOUT
*                   |                   |
*                   |                   |
*                   |                   |
*
*******************************************************************************/

#include <avr/io.h>
#include <avr/interrupt.h>

int main(void)
{

     DDRB = 0x01;                        // Setup PB0 as output 
     PORTD |= 0x04;                      // Activate pullupressistor of PD2
     GICR |= (1 << INT0);                // Enable INT0
     MCUCR |= (1 << ISC01)|(1 << ISC00); // INT0 is executed on rising edge

     sei();                              // Set the I-bit in SREG

     for(;;);                            // The main loop stays empty and 
                                         // could contain some code you want.

     return 0;                           // This line will never be executed
}


// Interrupt subroutine for external interrupt 0
 ISR(INT0_vect)                            
{
     PORTB ^= 0x01;                      // Toggle PB0

}